@@ -313,16 +313,22 @@ class Component(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ComponentType: 如果是 Component 控件类型，则可选类型为：
-TEXT - 单行文本
-MULTI_LINE_TEXT - 多行文本
-CHECK_BOX - 勾选框
-ATTACHMENT - 附件
-SELECTOR - 选择器
-如果是 SignComponent 控件类型，则可选类型为：
-SIGN_SEAL - 签署印章控件，静默签署时需要传入印章id作为ComponentValue
-SIGN_DATE - 签署日期控件
-SIGN_SIGNATURE - 手写签名控件，静默签署时不能使用
+        :param ComponentType: 如果是Component控件类型，则可选的字段为：
+TEXT - 普通文本控件；
+MULTI_LINE_TEXT - 多行文本控件；
+CHECK_BOX - 勾选框控件；
+FILL_IMAGE - 图片控件；
+DYNAMIC_TABLE - 动态表格控件；
+ATTACHMENT - 附件控件；
+SELECTOR - 选择器控件；
+
+如果是SignComponent控件类型，则可选的字段为
+SIGN_SEAL - 签署印章控件；
+SIGN_DATE - 签署日期控件；
+SIGN_SIGNATURE - 用户签名控件；
+SIGN_PERSONAL_SEAL - 个人签署印章控件（使用文件发起暂不支持此类型）；
+
+表单域的控件不能作为印章和签名控件
         :type ComponentType: str
         :param ComponentWidth: 参数控件宽度，单位pt
         :type ComponentWidth: float
@@ -358,8 +364,9 @@ ESIGN -- 个人印章类型
 TEXT - 文本内容
 MULTI_LINE_TEXT - 文本内容
 CHECK_BOX - true/false
-ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
+FILL_IMAGE、ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
 SELECTOR - 选项值
+DYNAMIC_TABLE - 传入json格式的表格内容，具体见数据结构FlowInfo：https://cloud.tencent.com/document/api/1420/61525#FlowInfo
         :type ComponentValue: str
         :param IsFormType: 是否是表单域类型，默认不存在
         :type IsFormType: bool
@@ -488,40 +495,40 @@ class CreateConvertTaskApiRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ResourceId: 资源Id
-        :type ResourceId: str
         :param ResourceType: 资源类型 取值范围doc,docx,html之一
         :type ResourceType: str
-        :param ResourceName: 资源名称
+        :param ResourceName: 资源名称，长度限制为256字符
         :type ResourceName: str
-        :param Organization: 无
-        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
-        :param Operator: 无
+        :param ResourceId: 资源Id，通过UploadFiles获取
+        :type ResourceId: str
+        :param Operator: 操作者信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param Agent: 无
+        :param Agent: 应用号信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        :param Organization: 暂未开放
+        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
         """
-        self.ResourceId = None
         self.ResourceType = None
         self.ResourceName = None
-        self.Organization = None
+        self.ResourceId = None
         self.Operator = None
         self.Agent = None
+        self.Organization = None
 
 
     def _deserialize(self, params):
-        self.ResourceId = params.get("ResourceId")
         self.ResourceType = params.get("ResourceType")
         self.ResourceName = params.get("ResourceName")
-        if params.get("Organization") is not None:
-            self.Organization = OrganizationInfo()
-            self.Organization._deserialize(params.get("Organization"))
+        self.ResourceId = params.get("ResourceId")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        if params.get("Organization") is not None:
+            self.Organization = OrganizationInfo()
+            self.Organization._deserialize(params.get("Organization"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1159,7 +1166,7 @@ class DescribeFlowBriefsRequest(AbstractModel):
         r"""
         :param Operator: 调用方用户信息，userId 必填
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowIds: 需要查询的流程ID列表
+        :param FlowIds: 需要查询的流程ID列表，限制最大20个
         :type FlowIds: list of str
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
@@ -1223,7 +1230,7 @@ class DescribeFlowTemplatesRequest(AbstractModel):
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param Filters: 搜索条件，具体参考Filter结构体。本接口取值：template-id：按照【 **模板唯一标识** 】进行过滤
         :type Filters: list of Filter
-        :param Limit: 查询个数，默认20，最大100
+        :param Limit: 查询个数，默认20，最大200
         :type Limit: int
         :param Offset: 查询偏移位置，默认0
         :type Offset: int
@@ -1585,12 +1592,13 @@ class FormField(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ComponentValue: 控件填充value，ComponentType和传入值类型对应关系：
+        :param ComponentValue: 控件填充vaule，ComponentType和传入值类型对应关系：
 TEXT - 文本内容
 MULTI_LINE_TEXT - 文本内容
 CHECK_BOX - true/false
-ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
-SELECTOR - 模板中配置的选项值
+FILL_IMAGE、ATTACHMENT - 附件的FileId，需要通过UploadFiles接口上传获取
+SELECTOR - 选项值
+DYNAMIC_TABLE - 传入json格式的表格内容，具体见数据结构FlowInfo：https://cloud.tencent.com/document/api/1420/61525#FlowInfo
         :type ComponentValue: str
         :param ComponentId: 控件id，和ComponentName选择一项传入即可
         :type ComponentId: str
@@ -1622,32 +1630,32 @@ class GetTaskResultApiRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param TaskId: 任务Id
+        :param TaskId: 任务Id，通过CreateConvertTaskApi得到
         :type TaskId: str
-        :param Organization: 企业信息
-        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
         :param Operator: 操作人信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param Agent: 渠道信息
+        :param Agent: 应用号信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        :param Organization: 暂未开放
+        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
         """
         self.TaskId = None
-        self.Organization = None
         self.Operator = None
         self.Agent = None
+        self.Organization = None
 
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
-        if params.get("Organization") is not None:
-            self.Organization = OrganizationInfo()
-            self.Organization._deserialize(params.get("Organization"))
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        if params.get("Organization") is not None:
+            self.Organization = OrganizationInfo()
+            self.Organization._deserialize(params.get("Organization"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1666,11 +1674,23 @@ class GetTaskResultApiResponse(AbstractModel):
         r"""
         :param TaskId: 任务Id
         :type TaskId: str
-        :param TaskStatus: 任务状态
+        :param TaskStatus: 任务状态，需要关注的状态
+0  :NeedTranform   - 任务已提交
+4  :Processing     - 文档转换中
+8  :TaskEnd        - 任务处理完成
+-2 :DownloadFailed - 下载失败
+-6 :ProcessFailed  - 转换失败
+-13:ProcessTimeout - 转换文件超时
         :type TaskStatus: int
-        :param TaskMessage: 状态描述
+        :param TaskMessage: 状态描述，需要关注的状态
+NeedTranform   - 任务已提交
+Processing     - 文档转换中
+TaskEnd        - 任务处理完成
+DownloadFailed - 下载失败
+ProcessFailed  - 转换失败
+ProcessTimeout - 转换文件超时
         :type TaskMessage: str
-        :param ResourceId: 资源Id
+        :param ResourceId: 资源Id，也是FileId，用于文件发起使用
         :type ResourceId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -2061,8 +2081,8 @@ class UploadFilesRequest(AbstractModel):
     def __init__(self):
         r"""
         :param BusinessType: 文件对应业务类型，用于区分文件存储路径：
-1. TEMPLATE - 模板； 文件类型：.pdf/.html
-2. DOCUMENT - 签署过程及签署后的合同文档 文件类型：.pdf/.html
+1. TEMPLATE - 模板； 文件类型：.pdf .doc .docx .html
+2. DOCUMENT - 签署过程及签署后的合同文档/图片控件 文件类型：.pdf/.jpg/.png
 3. SEAL - 印章； 文件类型：.jpg/.jpeg/.png
         :type BusinessType: str
         :param Caller: 调用方信息
