@@ -46,7 +46,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAgeDetectTask", params)
+            headers = request.headers
+            body = self.call("CreateAgeDetectTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAgeDetectTaskResponse()
@@ -74,7 +75,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateApp", params)
+            headers = request.headers
+            body = self.call("CreateApp", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAppResponse()
@@ -92,6 +94,64 @@ class GmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateScanUser(self, request):
+        """新增自定义送检用户
+
+        :param request: Request instance for CreateScanUser.
+        :type request: :class:`tencentcloud.gme.v20180711.models.CreateScanUserRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.CreateScanUserResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateScanUser", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateScanUserResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteScanUser(self, request):
+        """删除自定义送检用户
+
+        :param request: Request instance for DeleteScanUser.
+        :type request: :class:`tencentcloud.gme.v20180711.models.DeleteScanUserRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.DeleteScanUserResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteScanUser", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteScanUserResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAgeDetectTask(self, request):
         """查询年龄语音识别任务结果，请求频率10次/秒。该接口目前通过白名单开放试用，如有需求，请提交工单申请。
 
@@ -102,7 +162,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAgeDetectTask", params)
+            headers = request.headers
+            body = self.call("DescribeAgeDetectTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAgeDetectTaskResponse()
@@ -130,7 +191,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAppStatistics", params)
+            headers = request.headers
+            body = self.call("DescribeAppStatistics", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAppStatisticsResponse()
@@ -158,7 +220,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeApplicationData", params)
+            headers = request.headers
+            body = self.call("DescribeApplicationData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeApplicationDataResponse()
@@ -186,7 +249,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFilterResult", params)
+            headers = request.headers
+            body = self.call("DescribeFilterResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFilterResultResponse()
@@ -214,7 +278,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFilterResultList", params)
+            headers = request.headers
+            body = self.call("DescribeFilterResultList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFilterResultListResponse()
@@ -242,7 +307,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRealtimeScanConfig", params)
+            headers = request.headers
+            body = self.call("DescribeRealtimeScanConfig", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRealtimeScanConfigResponse()
@@ -270,7 +336,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRoomInfo", params)
+            headers = request.headers
+            body = self.call("DescribeRoomInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRoomInfoResponse()
@@ -299,7 +366,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeScanResultList", params)
+            headers = request.headers
+            body = self.call("DescribeScanResultList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeScanResultListResponse()
@@ -327,7 +395,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeUserInAndOutTime", params)
+            headers = request.headers
+            body = self.call("DescribeUserInAndOutTime", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeUserInAndOutTimeResponse()
@@ -355,7 +424,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAppStatus", params)
+            headers = request.headers
+            body = self.call("ModifyAppStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAppStatusResponse()
@@ -383,7 +453,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyRoomInfo", params)
+            headers = request.headers
+            body = self.call("ModifyRoomInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyRoomInfoResponse()
@@ -401,6 +472,35 @@ class GmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyUserMicStatus(self, request):
+        """修改用户麦克风状态。
+
+        :param request: Request instance for ModifyUserMicStatus.
+        :type request: :class:`tencentcloud.gme.v20180711.models.ModifyUserMicStatusRequest`
+        :rtype: :class:`tencentcloud.gme.v20180711.models.ModifyUserMicStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyUserMicStatus", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyUserMicStatusResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ScanVoice(self, request):
         """本接口(ScanVoice)用于提交语音检测任务，检测任务列表最多支持100个。使用前请您登录[控制台 - 服务配置](https://console.cloud.tencent.com/gamegme/conf)开启语音分析服务。
         </br></br>
@@ -545,7 +645,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ScanVoice", params)
+            headers = request.headers
+            body = self.call("ScanVoice", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ScanVoiceResponse()
@@ -573,7 +674,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateScanRooms", params)
+            headers = request.headers
+            body = self.call("UpdateScanRooms", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateScanRoomsResponse()
@@ -601,7 +703,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateScanUsers", params)
+            headers = request.headers
+            body = self.call("UpdateScanUsers", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateScanUsersResponse()
@@ -631,7 +734,8 @@ class GmeClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("VoiceFilter", params)
+            headers = request.headers
+            body = self.call("VoiceFilter", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.VoiceFilterResponse()
